.. _deviate:

Coverity deviation description
==============================

Below items from mlx.traceability plugin are used to describe deviations for certain groups of items.

.. item:: STATIC_DEVIATE-MISRA_UNUSED_EXAMPLE Deviate this example

    This is s test for deviation item description which explains rationale behind group of errors triagged as
    intentional in Coverity.


